@@ -22,6 +22,8 @@
 #include <QtCore/QHash>
 #include <QGst/Global>
 
+namespace KTpCallPrivate {
+
 class DeviceElementFactory
 {
 public:
@@ -35,4 +37,6 @@ private:
     static void addStreamProperties(const QGst::ElementPtr element);
 };
 
+} // KTpCallPrivate
+
 #endif // DEVICE_ELEMENT_FACTORY_H
