@@ -31,6 +31,8 @@
 
 Q_DECLARE_METATYPE(QList<int>)
 
+namespace KTpCallPrivate {
+
 struct PhononIntegrationPrivate
 {
     PhononIntegrationPrivate()
@@ -95,6 +97,8 @@ QList<Phonon::DeviceAccessList> PhononIntegration::readDevices(Phonon::ObjectDes
     case Phonon::VideoCaptureDeviceType:
         return readVideoDevices(type, category);
         break;
+    default:
+        break;
     }
 
     return QList<Phonon::DeviceAccessList>();
@@ -253,3 +257,5 @@ QList<int> PhononIntegration::sortDevicesByCategoryPriority(Phonon::ObjectDescri
     s_priv->phononSettings.endGroup();
     return deviceList;
 }
+
+} // KTpCallPrivate
