@@ -82,9 +82,11 @@ void CallHandler::handleChannels(const Tp::MethodInvocationContextPtr<> & contex
             kDebug() << "Channel is not a Call channel. Ignoring";
             continue;
         }
-
-        //TODO handle multiple calls - queue them if there is an active one
-        CallManager *manager = new CallManager(callChannel, this);
+        //check if any call manager is already handling this channel
+	if (handledCallChannels.contains(callChannel)) {
+	    handledCallChannels.append(callChannel);
+	    CallManager *manager = new CallManager(callChannel, this);
+	}
     }
 
     context->setFinished();
